@@ -1,5 +1,5 @@
 """High-level XRPL exports."""
-from xrpl import account, clients, core, ledger, models, transaction, wallet
+from xrpl import account, clients, core, ledger, models, transaction, utils, wallet
 from xrpl.constants import CryptoAlgorithm, XRPLException
 
 __all__ = [
@@ -11,5 +11,6 @@ __all__ = [
     "ledger",
     "models",
     "transaction",
+    "utils",
     "wallet",
 ]
