@@ -3,7 +3,12 @@ from xrpl.asyncio.clients.async_json_rpc_client import AsyncJsonRpcClient
 from xrpl.asyncio.clients.async_websocket_client import AsyncWebsocketClient
 from xrpl.asyncio.clients.client import Client
 from xrpl.asyncio.clients.exceptions import XRPLRequestFailureException
-from xrpl.asyncio.clients.utils import json_to_response, request_to_json_rpc
+from xrpl.asyncio.clients.utils import (
+    json_to_response,
+    request_to_json_rpc,
+    request_to_websocket,
+    websocket_to_response,
+)
 
 __all__ = [
     "AsyncJsonRpcClient",
