@@ -1,5 +1,6 @@
 """Convenience utilities for the XRP Ledger"""
 
+from xrpl.utils.sidechain import create_cross_chain_payment
 from xrpl.utils.str_conversions import hex_to_str, str_to_hex
 from xrpl.utils.time_conversions import (
     XRPLTimeRangeException,
@@ -21,4 +22,5 @@ __all__ = [
     "posix_to_ripple_time",
     "XRPRangeException",
     "XRPLTimeRangeException",
+    "create_cross_chain_payment",
 ]
